<?php

namespace ACL\Controllers;

use ACL\Traits\TResponse;
use Exception;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use ACL\Services\Filioper as FilioperService;

class Filioper {

    use TResponse;

    /**
     * @var FilioperService
     */
    private $filioperService;

    public function __construct(FilioperService $filioperService)
    {
        $this->filioperService = $filioperService;
    }

    /**
     * @param Request $request
     * @throws Exception
     */
    public function findFilioper(Request $request)
    {
        try{
            $params = $request->getParameters();
            $cdoperador = !empty($params['CDOPERADOR']) ? $params['CDOPERADOR'] : null;
            $data = $this->filioperService->findFilioper($cdoperador);
            $this->sendResponse($data, 200);
        }catch(Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    /**
     * @param Request $request
     * @throws Exception
     */
    public function createFilioper(Request $request)
    {
        try{
            $dataset = $request->getParameters();
            $labels = $dataset[0]['aclNextLabelsTraductionLog'][0];
            $this->filioperService->createFilioper($dataset, $labels);
            $this->sendResponse([], 201);
        }catch(Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    /**
     * @param Request $request
     * @throws Exception|\Doctrine\DBAL\Driver\Exception
     */
    public function updateFilioper(Request $request)
    {
        try{
            $dataset = $request->getParameters();
            $labels = $dataset[0]['aclNextLabelsTraductionLog'][0];
            $this->filioperService->updateFilioper($dataset, $labels);
            $this->sendResponse(null, 204);
        }catch(Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    /**
     * @param Request $request
     * @throws Exception
     */
    public function deleteFilioper(Request $request)
    {
        try{
            $dataset = $request->getParameters();
            $labels = $dataset[0]['aclNextLabelsTraductionLog'][0];
            $this->filioperService->deleteFilioper($dataset, $labels);
            $this->sendResponse([], 201);
        }catch(Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}
