<?php

namespace ACL\Repositories;


use ACL\Traits\TQuery;
use Doctrine\ORM\EntityManager;

class Organizacao extends RepositoryBase {

    Use TQuery;

    protected $table = 'ORGANIZACAO';

    /** @var EntityManager */
    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        parent::__construct($this->table);
        $this->entityManager = $entityManager;
    }

    /**
     * @param $organizationId
     * @return array
     */
    public function findOrganizacao($organizationId): array
    {
        $query = "SELECT NRORG, NMORGANIZACAO
                    FROM ORGANIZACAO
                   WHERE NRORG = :NRORG";

        $params = array(
            "NRORG" => $organizationId
        );

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query, $params);
    }

    /**
     * @param $filter
     * @return mixed[]
     */
    public function findOrganizacaoRelacionadaByOperador($filter): array
    {
        $query = <<<SQL
            SELECT NRORG, NMORGANIZACAO AS NMORGANIZACAOOPER, NMRAZSOCIALORG
              FROM ORGANIZACAO
             WHERE 1 = 1
             $filter        
SQL;

        return $this->entityManager->getConnection()->fetchAllAssociative($query);
    }

    public function findOrgOrgoper($cdoperador, $nrorg): array
    {
        $query = "SELECT OPER.NRORG, OPER.NRORGANIZACAOOPER, OPER.NRORGREL, OPER.CDOPERADOR,
                         OPER.CDOPERINCLUSAO, OPER.IDATIVO, ORG.NMORGANIZACAO 
                    FROM ORGANIZACAO ORG
               LEFT JOIN ORGANIZACAOOPER OPER ON OPER.NRORGREL = ORG.NRORG
                   WHERE ORG.NRORG = :NRORG
                     AND CDOPERADOR = :CDOPERADOR";

        $params = array(
            "CDOPERADOR" => $cdoperador,
            "NRORG" => $nrorg
        );

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query, $params);
    }

    public function findOrgOrgoperToRelate($cdoperador): array
    {
        $query = "SELECT NRORG, NMORGANIZACAO, IDATIVO
                  FROM ORGANIZACAO
                 WHERE NRORG NOT IN (SELECT NRORGREL
                                       FROM ORGANIZACAOOPER
                                      WHERE CDOPERADOR = :CDOPERADOR)
                   AND NRORG = (SELECT NRORGTRAB
                                  FROM OPERADOR
                                 WHERE CDOPERADOR = :CDOPERADOR)";

        $params = array(
            "CDOPERADOR" => $cdoperador,
        );

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query, $params);
    }
}
