<?php

namespace ACL\Services;

use ACL\Helpers\Instances\InstanceProvider;
use ACL\Repositories\Filioper as FilioperRepository;
use Exception;
use Teknisa\Libs\Util\Environment;
use ACL\Util\AclUtilities;

class Filioper
{

    /**
     * @var Environment
     */
    private $libEnvironment;

    /**
     * @var FilioperRepository
     */
    private $filioperRepository;

    public function __construct(FilioperRepository $filioperRepository)
    {
        $this->filioperRepository = $filioperRepository;
        $this->libEnvironment =  InstanceProvider::getLibEnvironment();
    }

    public function findFilioper($cdoperador): array
    {
        $filters = "AND CDOPERADOR = '{$cdoperador}'";
        return $this->filioperRepository->findFilioper(getNrorg(), $filters);
    }

    /**
     * @param $dataset
     * @throws Exception|\Doctrine\DBAL\Driver\Exception
     *
     */
    public function createFilioper($dataset, $labels)
    {
        foreach ($dataset as $row) {
            $this->filioperRepository->create(
                $row['CDOPERADOR'], $row['CDFILIAL'], getNrorg(), getCurrentUserId(), $row['DTVALIDADE']
            );
            $valores = [$labels['label'], $row['CDOPERADOR'], $row['CDFILIAL'], $row['DTVALIDADE']];
            $nomes = ["Tela", $labels['CDOPERADOR'], $labels['CDFILIAL'], $labels['DTVALIDADE']];
            $descricao = AclUtilities::gerarDescricao($valores, $nomes);
            InstanceProvider::getLibLog()->logRegister($row['CDOPERADOR'].'_'.$row['CDFILIAL'], $descricao, '1', 'FILIOPER', '/filioper');
        }
    }

    /**
     * @param $dataset
     * @throws \Doctrine\DBAL\Driver\Exception
     */
    public function updateFilioper($dataset, $labels)
    {
        foreach ($dataset as $row) {
            $filiOperAntigo =  $this->filioperRepository->findFiliOperAntigo( $row['CDOPERADOR'], $row['CDFILIAL']);
            if ($filiOperAntigo[0]['DTVALIDADE'] !== $row['DTVALIDADE']) {
                $valores = [$labels['label'], $row['DTVALIDADE']];
                $nomes = ["Tela", $labels['DTVALIDADE']];
                $descricao = AclUtilities::gerarDescricao($valores, $nomes);
                InstanceProvider::getLibLog()->logRegister($row['CDOPERADOR'].'_'.$row['CDFILIAL'], $descricao, '2', 'FILIOPER', '/filioper');
            }
            $this->filioperRepository->updateFilioper(
                $row['CDOPERADOR'], $row['CDFILIAL'], getNrorg(), $row['DTVALIDADE'], $row['IDATIVO']
            );
        }
    }

    /**
     * @param $dataset
     * @throws \Doctrine\DBAL\Driver\Exception
     */
    public function deleteFilioper($dataset, $labels)
    {
        foreach ($dataset as $row) {
            $this->filioperRepository->deleteFilioper($row['CDOPERADOR'], $row['CDFILIAL'], getNrorg());
            $valores = [$labels['label'], $row['CDOPERADOR'], $row['CDFILIAL']];
            $nomes = ["Tela", $labels['CDOPERADOR'], $labels['CDFILIAL']];
            $descricao = AclUtilities::gerarDescricao($valores, $nomes);
            InstanceProvider::getLibLog()->logRegister($row['CDOPERADOR'].'_'.$row['CDFILIAL'], $descricao, '3', 'FILIOPER', '/filioper');
        }
    }
}
