<?php

namespace ACL\Services;

use ACL\Helpers\Instances\InstanceProvider;
use ACL\Repositories\Opergrupop as OpergrupopRepository;
use Exception;
use Teknisa\Libs\Util\Environment;
use ACL\Util\AclUtilities;

class Opergrupop
{

    /**
     * @var Environment
     */
    private $libEnvironment;

    /**
     * @var OpergrupopRepository
     */
    private $opergrupopRepository;

    public function __construct(OpergrupopRepository $opergrupopRepository)
    {
        $this->opergrupopRepository = $opergrupopRepository;
        $this->libEnvironment =  InstanceProvider::getLibEnvironment();
    }

    /**
     * @param $cdoperador
     * @param $sqlOperator
     * @return array
     */
    public function findOpergrupopByOperador($cdoperador, $sqlOperator): array
    {
        if ($sqlOperator == 'IN') {
            return $this->opergrupopRepository->findOpergrupopByOperador($cdoperador, getNrorg());
        }
        return $this->opergrupopRepository->findGrupoperNotInOpergrupop($cdoperador, getNrorg());
    }

    /**
     * @param $params
     * @throws \Doctrine\DBAL\Driver\Exception
     */
    public function createOpergrupop($params, $labels)
    {
        foreach ($params as $row) {
            $this->opergrupopRepository->createOpergrupop(
                $row['CDGRUPOPER'], $row['CDOPERADOR'], 'N', getNrorg(), getCurrentUserId()
            );
            $valores = [$labels['label'], $row['CDGRUPOPER'], $row['CDOPERADOR'], 'N'];
            $nomes = ["Tela", $labels['CDGRUPOPER'], $labels['CDOPERADOR'], $labels['IDMENUPRINOP']];
            $descricao = AclUtilities::gerarDescricao($valores, $nomes);
            InstanceProvider::getLibLog()->logRegister($row['CDGRUPOPER'].'_'.$row['CDOPERADOR'], $descricao, '1', 'OPERGRUPOP', '/operador/opergrupop');
        }
    }

    /**
     * @param $cdgrupoper
     * @param $cdoperador
     * @param $idmenuprinop
     * @throws \Doctrine\DBAL\Driver\Exception
     */
    public function updateOpergrupop($cdgrupoper, $cdoperador, $idmenuprinop, $labels)
    {
        $cdgrupoper = (string)$cdgrupoper;
        if (strlen($cdgrupoper) < 2) {
            $cdgrupoper = str_pad($cdgrupoper, 2, '0', STR_PAD_LEFT);
        }

        $nrorg =  getNrorg();
        if ($idmenuprinop == 'S') {
            $opergrupop = $this->opergrupopRepository->findOpergrupopByOperador($cdoperador, $nrorg);
            foreach ($opergrupop['data'] as $row) {
                if ($row['CDGRUPOPER'] === $cdgrupoper) {
                    $valores = [$labels['label'], 'S'];
                    $nomes = ["Tela", $labels['IDMENUPRINOP']];
                    $descricao = AclUtilities::gerarDescricao($valores, $nomes);
                    InstanceProvider::getLibLog()->logRegister($row['CDGRUPOPER'].'_'.$row['CDOPERADOR'], $descricao, '2', 'OPERGRUPOP', '/operador/opergrupop');
                    $this->opergrupopRepository->updateOpergrupop($row['CDGRUPOPER'], $row['CDOPERADOR'], 'S', $nrorg);
                } else if ($row['IDMENUPRINOP'] == 'S') {
                    $valores = [$labels['label'], 'N'];
                    $nomes = ["Tela", $labels['IDMENUPRINOP']];
                    $descricao = AclUtilities::gerarDescricao($valores, $nomes);
                    InstanceProvider::getLibLog()->logRegister($row['CDGRUPOPER'].'_'.$row['CDOPERADOR'], $descricao, '2', 'OPERGRUPOP', '/operador/opergrupop');
                    $this->opergrupopRepository->updateOpergrupop($row['CDGRUPOPER'], $row['CDOPERADOR'], 'N', $nrorg);
                }
            }
        } else {
            $valores = [$labels['label'], 'N'];
            $nomes = ["Tela", $labels['IDMENUPRINOP']];
            $descricao = AclUtilities::gerarDescricao($valores, $nomes);
            InstanceProvider::getLibLog()->logRegister($cdgrupoper.'_'.$cdoperador, $descricao, '2', 'OPERGRUPOP', '/operador/opergrupop');
            $this->opergrupopRepository->updateOpergrupop($cdgrupoper, $cdoperador, 'N', $nrorg);
        }
    }

    /**
     * @param $params
     * @throws \Doctrine\DBAL\Driver\Exception
     */
    public function deleteOpergrupop($params, $labels)
    {
        foreach ($params as $row) {
            $valores = [$labels['label'], $row['CDGRUPOPER'], $row['CDOPERADOR']];
            $nomes = ["Tela", $labels['CDGRUPOPER'], $labels['CDOPERADOR']];
            $descricao = AclUtilities::gerarDescricao($valores, $nomes);
            InstanceProvider::getLibLog()->logRegister($row['CDGRUPOPER'].'_'.$row['CDOPERADOR'], $descricao, '3', 'OPERGRUPOP', '/operador/opergrupop');
            $this->opergrupopRepository->daleteOpergrupop($row['CDGRUPOPER'], $row['CDOPERADOR'], getNrorg());
        }
    }
}
