import { Form } from '@zeedhi/common';
import { IFormSave, IFormSaveEvents } from '@/components/common/form-save/interfaces';
import { IEventParam } from '@zeedhi/core';

export class FormSave extends Form implements IFormSave {
	/* Form name */
	public name!: string;

	/* Form title */
	public title: string = '';

	/* Form events */
	public events!: IFormSaveEvents;

	public headerLeftSlot = [
		{
			name: '',
			component: 'ZdText',
			tag: 'h3',
			text: this.title,
		},
	];

	public HeaderRightSlot = [
		{
			name: '',
			component: 'ZdButton',
			icon: true,
			iconName: 'mdi-close',
			events: {
				click: this.closeModal.bind(this),
			},
		},
	];

	public footerLeftSlot = [];

	public footerRightSlot = [
		{
			name: '',
			component: 'ZdButton',
			label: 'Cancelar',
			outline: true,
			events: {
				click: this.cancelClick.bind(this),
			},
		},
		{
			name: '',
			component: 'ZdButton',
			label: 'Salvar',
			events: {
				click: this.saveClick.bind(this),
			},
		},
	];

	/**
	 * Form Save constructor
	 * @param props Form Save properties
	 */
	constructor(props: IFormSave) {
		super(props);
		this.title = this.getInitValue('title', props.title, this.title);
		this.name = this.getInitValue('name', props.name, this.name);

		this.setHeaderLeftSlot();
		this.setHeaderRightSlot();
		this.setHeaderRightSlot();

		this.createAccessors();
	}

	private setHeaderLeftSlot() {
		this.headerLeftSlot[0].name = `${this.name}_form_save_title`;
		this.headerLeftSlot[0].text = this.title;
	}

	private setHeaderRightSlot() {
		this.headerLeftSlot[0].name = `${this.name}_form_save_header_close_button`;
	}

	private setFooterRightSlot() {
		this.headerLeftSlot[0].name = `${this.name}_form_save_footer_cancel_button`;
		this.headerLeftSlot[1].name = `${this.name}_form_save_header_save_button`;
	}

	private closeModal({ event, element }: IEventParam<FormSave>) {
		if (this.events.closeModal) {
			this.events.closeModal({ event, element, component: this });
		}
	}

	private cancelClick({ event, element }: IEventParam<FormSave>) {
		if (this.events.cancelClick) {
			this.events.cancelClick({ event, element, component: this });
		}
	}

	private saveClick({ event, element }: IEventParam<FormSave>) {
		debugger;
		if (this.validate() && this.events.saveClick) {
			this.events.saveClick({ event, element, component: this });
		}
	}
}
